BMV Monitor / Serial Scripts
============================

About
------------

A python script to record data from Victron BMV-600S and BMV-602S

Preparations
------------

###PIP

`pip install BMV`

###Manual

```
cd /path/to/bmvmonitor
pip install -r requirements.txt
````

Contributors
-----------

- [Nick Otter](http://github.com/otternq)